==> ibm-cos-sdk-config-1.1.0.tar.gz: ibm-cos-sdk-config-1.1.0/README.md <==
# IBM COS Resource Configuration SDK for Python 

This package allows Python developers to write software that interacts with the Resource Configuration API for [IBM
Cloud Object Storage](https://cloud.ibm.com/apidocs/cos/cos-configuration).

## Documentation

* [Core documentation for IBM COS](https://cloud.ibm.com/docs/services/cloud-object-storage/getting-started.html)
* [REST API Reference and Code Examples](https://cloud.ibm.com/apidocs/cos/cos-configuration)
* [Python Resource Configuration API reference documentation](https://ibm.github.io/ibm-cos-sdk-python-config)

For release notes, see the [CHANGELOG](CHANGELOG.md).

## Quick start

You'll need:
  * An instance of COS.
  * An API key from [IBM Cloud Identity and Access Management](https://cloud.ibm.com/docs/iam/users_roles.html).
  * **Python 2.7, 3.4, 3.5, 3.6, or 3.7**.

  These values can be found in the IBM Cloud Console by [generating a 'service credential'](https://cloud.ibm.com/docs/services/cloud-object-storage/iam/service-credentials.html).

## Getting the SDK
The preferred way to install the IBM COS Resource Configuration SDK for Python is to use the
[pip](https://pypi.org/project/pip/) package manager. Simply type the following
into a terminal window:

```sh
pip install ibm-cos-sdk-config
```

## Getting Help
Feel free to use GitHub issues for tracking bugs and feature requests, but for help please use one of the following resources:

* Read a quick start guide in [IBM Cloud Docs](https://cloud.ibm.com/docs/services/cloud-object-storage/).
* Ask a question on [Stack Overflow](https://stackoverflow.com/) and tag it with ``ibm`` and ``object-storage``.
* Open a support ticket with [IBM Cloud Support](https://cloud.ibm.com/unifiedsupport/supportcenter)
* If it turns out that you may have found a bug, please [open an issue](https://github.com/ibm/ibm-cos-sdk-python-config/issues/new).


## License

This SDK is distributed under the
[Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0).

==> ibm-cos-sdk-config-1.1.1.tar.gz: ibm-cos-sdk-config-1.1.1/README.md <==
# IBM COS Resource Configuration SDK for Python 

This package allows Python developers to write software that interacts with the Resource Configuration API for [IBM
Cloud Object Storage](https://cloud.ibm.com/apidocs/cos/cos-configuration).

## Notice

IBM is officially deprecating support of Python versions 2.7 & 3.4.   All clients need to upgrade to version 3.5 or greater by January 31, 2020.

## Documentation

* [Core documentation for IBM COS](https://cloud.ibm.com/docs/services/cloud-object-storage/getting-started.html)
* [REST API Reference and Code Examples](https://cloud.ibm.com/apidocs/cos/cos-configuration)
* [Python Resource Configuration API reference documentation](https://ibm.github.io/ibm-cos-sdk-python-config)

For release notes, see the [CHANGELOG](CHANGELOG.md).

## Quick start

You'll need:
  * An instance of COS.
  * An API key from [IBM Cloud Identity and Access Management](https://cloud.ibm.com/docs/iam/users_roles.html).
  * **Python 3.5, 3.6, or 3.7**.

  These values can be found in the IBM Cloud Console by [generating a 'service credential'](https://cloud.ibm.com/docs/services/cloud-object-storage/iam/service-credentials.html).

## Getting the SDK
The preferred way to install the IBM COS Resource Configuration SDK for Python is to use the
[pip](https://pypi.org/project/pip/) package manager. Simply type the following
into a terminal window:

```sh
pip install ibm-cos-sdk-config
```

## Getting Help
Feel free to use GitHub issues for tracking bugs and feature requests, but for help please use one of the following resources:

* Read a quick start guide in [IBM Cloud Docs](https://cloud.ibm.com/docs/services/cloud-object-storage/).
* Ask a question on [Stack Overflow](https://stackoverflow.com/) and tag it with ``ibm`` and ``object-storage``.
* Open a support ticket with [IBM Cloud Support](https://cloud.ibm.com/unifiedsupport/supportcenter)
* If it turns out that you may have found a bug, please [open an issue](https://github.com/ibm/ibm-cos-sdk-python-config/issues/new).


## License

This SDK is distributed under the
[Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0).
